..
    Copyright (C) 2024 University of Münster.

    dnb-urn-service is free software; you can redistribute it and/or modify
    it under the terms of the MIT License; see LICENSE file for more details.

Changes
=======

Version 0.1.0 (released 2022-11-02)

- Initial non public release.

Version 0.1.1 (released 2023-02-13)

- First public release

Version 0.1.6 (released 2024-04-04)

- First automatic public release
